==> DevKit-Debugger-24.0.0-Linux-Kunpeng.tar.gz: DevKit-Debugger-24.0.0-Linux-Kunpeng/config/clean_rank_files.sh <==
#!/bin/bash
#Description: DevKit constants
#Copyright: Copyright © Huawei Technologies Co., Ltd. 2023. All rights reserved.
#History: 2024-01-10 created

RETURN_SUCCESS='SUCCESS'
RETURN_FAILED='FAILED'
USER_UUID_DIR_IS_LINK_ERROR='USER_UUID_DIR_IS_LINK_ERROR'
RANK_FILE_IS_LINK_ERROR='RANK_FILE_IS_LINK_ERROR'


function check_file_is_link() {
    if [[ -L ${user_uuid_path} ]]; then
        echo ${USER_UUID_DIR_IS_LINK_ERROR}
        return
    fi
    cd "${user_uuid_path}"
    for ((i=0; i<${num}; i++))
    do
        rank_file_name="rank${i}"
        if [[ -L ${rank_file_name} ]]; then
            echo ${RANK_FILE_IS_LINK_ERROR}
            return
        fi
    done
}

function clean_rank_file() {
    local time=0
    rm -rf "${user_uuid_path}"/rank*
    while (( ${time}<6 ))
    do
        sleep 1s
        list_file_cmd=$(ls ${user_uuid_path})
        if [[ ${list_file_cmd} != *rank* ]]; then
            rm -rf ${user_uuid_path}
            break
        fi
        kill_agent_cmd=$(ps -ef |grep ${user_uuid_path}/agent |grep -v color |awk '{print $2}' |xargs kill -9)
        rm -rf "${user_uuid_path}"/rank*
        let "time++"
    done
    if [[ -e ${user_uuid_path} ]]; then
        echo ${RETURN_FAILED}
        return
    fi
    echo ${RETURN_SUCCESS}
}

function clean_user_temp_file() {
    DEBUGGER_ENTRANCE_TEMP_PATH="/usr/bin/devkit/debugger_entrance/temp"
    uuid=$(basename "${user_uuid_path}")
    if [[ "${delete_nohup_flag}" == "True" ]]; then
        rm -rf "${DEBUGGER_ENTRANCE_TEMP_PATH}"/"${uuid}"
    else
        cd "${DEBUGGER_ENTRANCE_TEMP_PATH}"/"${uuid}"
        find ./ ! -name "nohup_mpirun.out" -type f -exec {} +
    fi
}


function main() {
    user_uuid_path="$1"
    rank_num="$2"
    delete_nohup_flag="$3"
    num=$(expr ${rank_num} + 0)
    check_file_is_link
    clean_rank_file
    clean_user_temp_file
}

main "$@"

==> DevKit-Debugger-25.0.0-Linux-Kunpeng.tar.gz: DevKit-Debugger-25.0.0-Linux-Kunpeng/config/clean_rank_files.sh <==
#!/bin/bash
#Description: DevKit constants
#Copyright: Copyright © Huawei Technologies Co., Ltd. 2023. All rights reserved.
#History: 2024-01-10 created

RETURN_SUCCESS='SUCCESS'
RETURN_FAILED='FAILED'
USER_UUID_DIR_IS_LINK_ERROR='USER_UUID_DIR_IS_LINK_ERROR'
RANK_FILE_IS_LINK_ERROR='RANK_FILE_IS_LINK_ERROR'


function check_file_is_link() {
    if [[ -L ${user_uuid_path} ]]; then
        echo ${USER_UUID_DIR_IS_LINK_ERROR}
        return
    fi
    cd "${user_uuid_path}"
    for ((i=0; i<${num}; i++))
    do
        rank_file_name="rank${i}"
        if [[ -L ${rank_file_name} ]]; then
            echo ${RANK_FILE_IS_LINK_ERROR}
            return
        fi
    done
}

function clean_rank_file() {
    local time=0
    rm -rf "${user_uuid_path}"/rank*
    while (( ${time}<6 ))
    do
        sleep 1s
        list_file_cmd=$(ls ${user_uuid_path})
        if [[ ${list_file_cmd} != *rank* ]]; then
            rm -rf ${user_uuid_path}
            break
        fi
        kill_agent_cmd=$(ps -ef |grep ${user_uuid_path}/agent |grep -v color |awk '{print $2}' |xargs kill -9)
        rm -rf "${user_uuid_path}"/rank*
        let "time++"
    done
    if [[ -e ${user_uuid_path} ]]; then
        echo ${RETURN_FAILED}
        return
    fi
    echo ${RETURN_SUCCESS}
}

function clean_user_temp_file() {
    DEBUGGER_ENTRANCE_TEMP_PATH="$debugger_entrance_temp_path"
    uuid=$(basename "${user_uuid_path}")
    if [[ "${delete_nohup_flag}" == "True" ]]; then
        rm -rf "${DEBUGGER_ENTRANCE_TEMP_PATH}"/"${uuid}"
    else
        cd "${DEBUGGER_ENTRANCE_TEMP_PATH}"/"${uuid}"
        find ./ ! -name "nohup_mpirun.out" -type f -exec {} +
    fi
}


function main() {
    user_uuid_path="$1"
    rank_num="$2"
    delete_nohup_flag="$3"
    debugger_entrance_temp_path="$4"
    num=$(expr ${rank_num} + 0)
    check_file_is_link
    clean_rank_file
    clean_user_temp_file
}

main "$@"
